@@ -1,14 +1,17 @@
 # pdnd_client/config.py
 
-import json
 import os
+import json
 
 # La classe Config viene inizializzata con un percorso verso un file di configurazione e una chiave di ambiente.
 # Legge la configurazione dal file e la memorizza in un dizionario.
 # Il metodo get consente di recuperare valori specifici della configurazione, con un valore predefinito opzionale.
 class Config:
     # Questo metodo inizializza l'oggetto Config caricando la configurazione da un file JSON.
-    def __init__(self, config_path, env: "produzione"):
+    def __init__(self, config_path: str = None, env: str ="produzione"):
+        if config_path is None:
+            config_path = os.path.join(os.path.dirname(__file__), "..", "configs", "sample.json")
+
         self.env = env
         with open(config_path, "r") as f:
             full_config = json.load(f)
